@@ -321,9 +321,8 @@ class _WiserRoom(object):
         Advance room schedule to the next scheduled time and temperature setting
         return: boolean
         """
-        return self.set_target_temperature(
-            tf._from_wiser_temp(self.schedule.next.setting)
-        )
+        if self.cancel_boost():
+            return self.set_target_temperature(self.schedule.next.setting)
 
     def cancel_overrides(self) -> bool:
         """
@@ -383,10 +382,12 @@ class _WiserRoomCollection(object):
 
     @property
     def all(self) -> list:
+        """Returns list of room objects"""
         return self._rooms
 
     @property
     def count(self) -> int:
+        """Number of rooms"""
         return len(self._rooms)
 
     def add(self, name):
